# [Changelog](https://github.com/michaeljoseph/pyconza2014/releases)

## [0.1.0](https://github.com/michaeljoseph/pyconza2014/compare/0.0.2...0.1.0)

* [d89ff3a](https://github.com/michaeljoseph/pyconza2014/commit/d89ff3a) Rm egg-info

## [0.0.2](https://github.com/michaeljoseph/pyconza2014/compare/0.0.1...0.0.2)

* [bf16a3d](https://github.com/michaeljoseph/pyconza2014/commit/bf16a3d) Init

## 0.0.1

* This version is first.